==> skim-1.0.3.tar.bz2: skim-1.0.3/plugins/inputwindow/inputwindow.h <==
/***************************************************************************
 *   Copyright (C) 2003 by liuspider                                       *
 *   liuspider@users.sourceforge.net                                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 **************************************************************************/

#ifndef INPUTWINDOW_H
#define INPUTWINDOW_H

#include "src/skimpluginmanager.h"
#include "scimdragableframe.h"

#include <kaction.h>

class ScimLineEdit;
class ScimLookupTable;
class ScimStringListItem;

class QVBoxLayout;
class QHBoxLayout;
class QLabel;

class inputWindow : public ScimDragableFrame
{
    Q_OBJECT

public:
    inputWindow( SkimPluginManager*, QWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
    ~inputWindow();
    void toggleStick();

    ScimLineEdit* PreEditText;
    ScimStringListItem* AuxText;
    ScimLookupTable* LookupLbl;

public slots:
    virtual void adjustSize();
    
    virtual void updateAuxString( const QString &, const scim::AttributeList & );
    virtual void updateLookupTable( const QStringList&, const QStringList&, 
          QValueList<scim::AttributeList> &, int, unsigned, unsigned, unsigned & );
    virtual void updatePreeditString(const QString &, const scim::AttributeList &);
    virtual void updateSpotLocation( int, int );
    
    virtual void showAuxString();
    virtual void showLookupTable();
    virtual void showPreeditString();
    
    virtual void hideAuxString();
    virtual void hideLookupTable();
    virtual void hidePreeditString();
    
    virtual void changeSetting();

protected:
    QVBoxLayout* inputWindowLayout;
    QHBoxLayout* bottomLineLayout;

protected slots:
    virtual void languageChange();
//     void toggleSticky();

private:
    SkimPluginManager* allModules;
    scim::SocketServerThread* InputServer;
    bool sticky;
    QRect ScreenRect;
    KToggleAction* StickAction;
};

#include "src/skimplugin.h"

class InputWindowPlugin : public SkimPlugin
{
Q_OBJECT
public:
    InputWindowPlugin( QObject *parent, const char *name, const QStringList &args );

    virtual ~InputWindowPlugin();
public slots:
    void toggleStick();
private:
    inputWindow* inputw;
};

#endif // INPUTWINDOW_H

==> skim-1.2.0.tar.bz2: skim-1.2.0/plugins/inputwindow/inputwindow.h <==
/***************************************************************************
 *   Copyright (C) 2003-2005 by liuspider                                  *
 *   liuspider@users.sourceforge.net                                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 **************************************************************************/

#ifndef INPUTWINDOW_H
#define INPUTWINDOW_H

#include "src/skimpluginmanager.h"
#include "scimdragableframe.h"

#include <kaction.h>

class ScimLineEdit;
class ScimLookupTable;
class ScimStringListItem;

class QVBoxLayout;
class QHBoxLayout;
class QLabel;

class inputWindow : public ScimDragableFrame
{
    Q_OBJECT

public:
    inputWindow( SkimPluginManager*, QWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
    ~inputWindow();
    void toggleStick();

    ScimLineEdit* PreEditText;
    ScimStringListItem* AuxText;
    ScimLookupTable* LookupLbl;

public slots:
    virtual void adjustSize();
    
    virtual void updateAuxString( const QString &, const scim::AttributeList & );
    virtual void updateLookupTable( const QStringList&, const QStringList&, 
          QValueList<scim::AttributeList> &, int, int, scim::uint32, size_t & );
    virtual void updatePreeditString(const QString &, const scim::AttributeList &);
    virtual void updateSpotLocation( int, int );
    
    virtual void showAuxString();
    virtual void showLookupTable();
    virtual void showPreeditString();
    
    virtual void hideAuxString();
    virtual void hideLookupTable();
    virtual void hidePreeditString();
    
    virtual void changeSetting();

protected:
    QVBoxLayout* inputWindowLayout;
    QHBoxLayout* bottomLineLayout;

protected slots:
    virtual void languageChange();
//     void toggleSticky();

private:
    SkimPluginManager* allModules;
    scim::SocketServerThread* InputServer;
    bool sticky;
    QRect ScreenRect;
    KToggleAction* StickAction;
};

#include "src/skimplugin.h"

class InputWindowPlugin : public SkimPlugin
{
Q_OBJECT
public:
    InputWindowPlugin( QObject *parent, const char *name, const QStringList &args );

    virtual ~InputWindowPlugin();
public slots:
    void toggleStick();
private:
    inputWindow* inputw;
};

#endif // INPUTWINDOW_H
